# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin
from . import models


class NotificationAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('subject',)
    advanced_search_fields = (
        ('status',),
        ('subject__icontains',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': (('subject', 'slug'), 'body', 'call_to_action_label', 'call_to_action_url')
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('pk', 'status', 'subject', 'ordering')
    list_display_links = ('subject',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    prepopulated_fields = {"slug": ("subject",)}


class NotificationRecipientAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('user__last_name', 'user__first_name',)
    advanced_search_fields = (
        ('status',),
        ('user__last_name__icontains', 'user__first_name__icontains',),
        ('notification__subject__icontains',),
        ('reading_date__gte', 'reading_date__lte',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': ('user', 'notification', 'reading_date')
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('pk', 'status', 'notification', 'user', 'reading_date', 'ordering')
    list_display_links = ('user',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    autocomplete_fields = ('notification', 'user',)


admin.site.register(models.Notification, NotificationAdmin)
admin.site.register(models.NotificationRecipient, NotificationRecipientAdmin)
