# -*- coding: utf-8 -*-

from django.contrib.auth import get_user_model
from django.core.exceptions import PermissionDenied
from django.db import models
from django.utils.translation import ugettext_lazy as _

from thx.core.models import UserModel, DateModel, StatusModel, OrderedModel, CleanModel


User = get_user_model()


class Notification(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    subject = models.CharField(
        max_length=20,
        verbose_name=_('subject'),
    )
    slug = models.SlugField(
        max_length=20,
        verbose_name=_('slug'),
    )
    body = models.TextField(
        verbose_name=_('body'),
    )
    call_to_action_label = models.CharField(
        max_length=255,
        blank=True, null=True,
        verbose_name=_('call to action label'),
    )
    call_to_action_url = models.URLField(
        blank=True, null=True,
        verbose_name=_('call to action url'),
    )

    class Meta:
        verbose_name = _('notification')
        verbose_name_plural = _('notifications')
        ordering = ('ordering', '-date_create',)
        permissions = (
            ("list_notification", "Can list notification"),
            ("detail_notification", "Can detail notification"),
            ("enable_notification", "Can enable notification"),
            ("disable_notification", "Can disable notification"),
        )

    def __str__(self):
        return self.subject


class NotificationRecipient(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    user = models.ForeignKey(
        User,
        on_delete=models.CASCADE,
        related_name='notifications',
        verbose_name=_('user'),
    )
    notification = models.ForeignKey(
        Notification,
        on_delete=models.CASCADE,
        related_name='notification_recipients',
        verbose_name=_('notification'),
    )
    reading_date = models.DateTimeField(
        blank=True, null=True,
        verbose_name=_('reading date')
    )

    class Meta:
        verbose_name = _('notification recipient')
        verbose_name_plural = _('notification recipients')
        ordering = ('ordering', '-notification__date_create')
        permissions = (
            ("list_notificationrecipient", "Can list notification recipient"),
            ("detail_notificationrecipient", "Can detail notification recipient"),
            ("enable_notificationrecipient", "Can enable notification recipient"),
            ("disable_notificationrecipient", "Can disable notification recipient"),
        )
        unique_together = ('user', 'notification')

    def __str__(self):
        return '{}-{}'.format(self.user, self.notification)
